[][src]Enum ruma_identifiers::Error

pub enum Error {
    EmptyRoomVersionId,
    InvalidCharacters,
    InvalidKeyAlgorithm,
    InvalidKeyVersion,
    InvalidServerName,
    MaximumLengthExceeded,
    MissingDelimiter,
    MissingLeadingSigil,
}

An error encountered when trying to parse an invalid ID string.

Variants

EmptyRoomVersionId

The room version ID is empty.

InvalidCharacters

The ID's localpart contains invalid characters.

Only relevant for user IDs.

InvalidKeyAlgorithm

The key algorithm is invalid (e.g. empty).

InvalidKeyVersion

The key version contains outside of [a-zA-Z0-9_].

InvalidServerName

The server name part of the the ID string is not a valid server name.

MaximumLengthExceeded

The ID exceeds 255 bytes (or 32 codepoints for a room version ID).

MissingDelimiter

The ID is missing the colon delimiter between localpart and server name, or between key algorithm and key name / version.

MissingLeadingSigil

The ID is missing the correct leading sigil.