Enum ruma_identifiers::RoomVersionId [−][src]
pub enum RoomVersionId {
Version1,
Version2,
Version3,
Version4,
Version5,
Version6,
// some variants omitted
}Expand description
A Matrix room version ID.
A RoomVersionId can be or converted or deserialized from a string slice, and can be converted
or serialized back into a string as needed.
assert_eq!(RoomVersionId::try_from("1").unwrap().as_ref(), "1");
Any string consisting of at minimum 1, at maximum 32 unicode codepoints is a room version ID.
Custom room versions or ones that were introduced into the specification after this code was
written are represented by a hidden enum variant. You can still construct them the same, and
check for them using one of RoomVersionIds PartialEq implementations or through .as_str().
Variants
A version 1 room.
A version 2 room.
A version 3 room.
A version 4 room.
A version 5 room.
A version 6 room.
Implementations