Enum ruma_identifiers::SigningKeyAlgorithm [−][src]
#[non_exhaustive]
pub enum SigningKeyAlgorithm {
Ed25519,
// some variants omitted
}Expand description
The signing key algorithms defined in the Matrix spec.
This type can hold an arbitrary string. To check for algorithms that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
The Ed25519 signature algorithm.