Struct ruma_identifiers::DeviceId [−][src]
#[repr(transparent)]pub struct DeviceId(_);
A Matrix key ID.
Device identifiers in Matrix are completely opaque character sequences. This type is provided simply for its semantic value.
Implementations