Struct ruma_identifiers::KeyName[][src]

#[repr(transparent)]pub struct KeyName(_);

A Matrix key identifier.

Key identifiers in Matrix are opaque character sequences of [a-zA-Z_]. This type is provided simply for its semantic value.

Implementations

impl KeyName[src]

pub fn as_str(&self) -> &str[src]

Creates a string slice from this KeyName.

pub fn as_bytes(&self) -> &[u8][src]

Creates a byte slice from this KeyName.