Struct ruma_identifiers::ServerName [−][src]
#[repr(transparent)]pub struct ServerName(_);
A Matrix-spec compliant server name.
Implementations
impl ServerName[src]
impl ServerName[src]Trait Implementations
impl Debug for ServerName[src]
impl Debug for ServerName[src]impl Display for ServerName[src]
impl Display for ServerName[src]impl Hash for ServerName[src]
impl Hash for ServerName[src]impl Ord for ServerName[src]
impl Ord for ServerName[src]impl PartialEq<&'_ str> for ServerName[src]
impl PartialEq<&'_ str> for ServerName[src]impl PartialEq<ServerName> for ServerName[src]
impl PartialEq<ServerName> for ServerName[src]fn eq(&self, other: &ServerName) -> bool[src]
fn eq(&self, other: &ServerName) -> bool[src]This method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(&self, other: &ServerName) -> bool[src]
fn ne(&self, other: &ServerName) -> bool[src]This method tests for !=.
impl PartialEq<String> for ServerName[src]
impl PartialEq<String> for ServerName[src]impl PartialEq<str> for ServerName[src]
impl PartialEq<str> for ServerName[src]impl PartialOrd<ServerName> for ServerName[src]
impl PartialOrd<ServerName> for ServerName[src]fn partial_cmp(&self, other: &ServerName) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &ServerName) -> Option<Ordering>[src]This method returns an ordering between self and other values if one exists. Read more
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Serialize for ServerName[src]
impl Serialize for ServerName[src]impl ToOwned for ServerName[src]
impl ToOwned for ServerName[src]type Owned = Box<ServerName>
type Owned = Box<ServerName>The resulting type after obtaining ownership.
fn to_owned(&self) -> Self::Owned[src]
fn to_owned(&self) -> Self::Owned[src]Creates owned data from borrowed data, usually by cloning. Read more
fn clone_into(&self, target: &mut Self::Owned)[src]
fn clone_into(&self, target: &mut Self::Owned)[src]🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<'a> TryFrom<&'a str> for &'a ServerName[src]
impl<'a> TryFrom<&'a str> for &'a ServerName[src]