Struct ruma_identifiers::UserId [−][src]
pub struct UserId { /* fields omitted */ }Expand description
A Matrix user ID.
A UserId is generated randomly or converted from a string slice, and can be converted back
into a string as needed.
assert_eq!( UserId::try_from("@carl:example.com").unwrap().as_ref(), "@carl:example.com" );
Implementations
This is supported on crate feature rand only.
rand only.Attempts to generate a UserId for the given origin server with a localpart consisting of
12 random ASCII characters.
pub fn parse_with_server_name(
id: impl AsRef<str> + Into<Box<str>>,
server_name: &ServerName
) -> Result<Self, Error>
pub fn parse_with_server_name(
id: impl AsRef<str> + Into<Box<str>>,
server_name: &ServerName
) -> Result<Self, Error>Attempts to complete a user ID, by adding the colon + server name and @ prefix, if not
present already.
This is a convenience function for the login API, where a user can supply either their full
user ID or just the localpart. It only supports a valid user ID or a valid user ID
localpart, not the localpart plus the @ prefix, or the localpart plus server name without
the @ prefix.
Returns the server name of the user ID.
Whether this user ID is a historical one, i.e. one that doesn’t conform to the latest specification of the user ID grammar but is still accepted because it was previously allowed.