[][src]Enum ruma_identifiers::Error

pub enum Error {
    InvalidCharacters,
    InvalidHost,
    MaximumLengthExceeded,
    MinimumLengthNotSatisfied,
    MissingDelimiter,
    MissingSigil,
}

An error encountered when trying to parse an invalid ID string.

Variants

InvalidCharacters

The ID's localpart contains invalid characters.

Only relevant for user IDs.

InvalidHost

The domain part of the the ID string is not a valid IP address or DNS name.

MaximumLengthExceeded

The ID exceeds 255 bytes (or 32 codepoints for a room version ID.)

MinimumLengthNotSatisfied

The ID is less than 4 characters (or is an empty room version ID.)

MissingDelimiter

The ID is missing the colon delimiter between localpart and server name.

MissingSigil

The ID is missing the leading sigil.