[−][src]Enum ruma_identifiers::Error
An error encountered when trying to parse an invalid ID string.
Variants
InvalidCharactersThe ID's localpart contains invalid characters.
Only relevant for user IDs.
InvalidHostThe domain part of the the ID string is not a valid IP address or DNS name.
MaximumLengthExceededThe ID exceeds 255 bytes.
MinimumLengthNotSatisfiedThe ID is less than 4 characters.
MissingDelimiterThe ID is missing the colon delimiter between localpart and server name.
MissingSigilThe ID is missing the leading sigil.