[][src]Struct ruma_identifiers::UserId

pub struct UserId { /* fields omitted */ }

A Matrix user ID.

A UserId is generated randomly or converted from a string slice, and can be converted back into a string as needed.

assert_eq!(
    UserId::try_from("@carl:example.com").unwrap().to_string(),
    "@carl:example.com"
);

Methods

impl UserId[src]

pub fn new(homeserver_host: &str) -> Result<Self, Error>[src]

Attempts to generate a UserId for the given origin server with a localpart consisting of 12 random ASCII characters.

Fails if the given homeserver cannot be parsed as a valid host.

pub fn hostname(&self) -> &Host[src]

Returns a Host for the user ID, containing the server name (minus the port) of the originating homeserver.

The host can be either a domain name, an IPv4 address, or an IPv6 address.

pub fn localpart(&self) -> &str[src]

Returns the user's localpart.

pub fn port(&self) -> u16[src]

Returns the port the originating homeserver can be accessed on.

pub fn is_historical(&self) -> bool[src]

Whether this user ID is a historical one, i.e. one that doesn't conform to the latest specification of the user ID grammar but is still accepted because it was previously allowed.